==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/PicnicMatRender.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.block.BlockPicnicMat;
import com.github.tartaricacid.touhoulittlemaid.client.model.PicnicMatModel;
import com.github.tartaricacid.touhoulittlemaid.tileentity.TileEntityPicnicMat;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_827;

public class PicnicMatRender implements class_827<TileEntityPicnicMat> {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/entity/picnic_mat.png");
    private final PicnicMatModel model;
    private final class_5614.class_5615 context;

    public PicnicMatRender(class_5614.class_5615 context) {
        this.model = new PicnicMatModel(context.method_32140(PicnicMatModel.LAYER));
        this.context = context;
    }

    @Override
    public void render(TileEntityPicnicMat picnicMat, float partialTick, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        class_2680 blockState = picnicMat.method_11010();
        if (blockState.method_11654(BlockPicnicMat.PART).isCenter()) {
            class_2350 facing = blockState.method_11654(BlockPicnicMat.FACING);
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            poseStack.method_22907(class_7833.field_40715.rotationDegrees(180 - facing.method_10161() * 90));
            {
                this.model.getHideModel().method_32086("basketHide").field_3665 = !picnicMat.isEmpty(0);
                this.model.getHideModel().method_32086("breadHide").field_3665 = !picnicMat.isEmpty(1);
                this.model.getHideModel().method_32086("cakeHide").field_3665 = !picnicMat.isEmpty(2);
            }
            {
                renderFood(picnicMat, 3, -0.6f, -1.5f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 4, 0.15f, -1.2f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 5, 0.55f, -1.6f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);

                renderFood(picnicMat, 6, -0.5f, 1.65f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 7, 0.375f, 1.575f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 8, -0.05f, 1.2f, 1.25f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
            }
            class_4588 buffer = bufferIn.getBuffer(class_1921.method_23578(TEXTURE));
            model.renderToBuffer(poseStack, buffer, combinedLightIn, combinedOverlayIn, 1.0F, 1.0F, 1.0F, 1.0F);
            poseStack.method_22909();
        }
    }

    private void renderFood(TileEntityPicnicMat picnicMat, int slotId, float x, float y, float z, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        class_1799 storageItem = picnicMat.getStorageItem(slotId);
        if (!storageItem.method_7960()) {
            int count = storageItem.method_7947();
            poseStack.method_22903();
            poseStack.method_22907(class_7833.field_40713.rotationDegrees(90));
            poseStack.method_46416(x, y, z);
            poseStack.method_22905(0.4f, 0.4f, 0.4f);
            context.method_43335().method_23178(storageItem, class_811.field_4319, combinedLightIn, combinedOverlayIn, poseStack, bufferIn, picnicMat.method_10997(), 0);
            if (count >= 10) {
                int stackCount = count / 10;
                for (int i = 0; i < stackCount; i++) {
                    poseStack.method_22904(Math.sin(i) * 0.05, Math.cos(i) * 0.03, -0.07);
                    poseStack.method_22907(class_7833.field_40717.rotationDegrees((float) Math.cos(i) * 60));
                    context.method_43335().method_23178(storageItem, class_811.field_4319, combinedLightIn, combinedOverlayIn, poseStack, bufferIn, picnicMat.method_10997(), 0);
                }
            }
            poseStack.method_22909();
        }
    }

    @Override
    public boolean shouldRenderOffScreen(TileEntityPicnicMat te) {
        return true;
    }

    // TODO
/*    @Override
    public AABB getRenderBoundingBox(TileEntityPicnicMat te) {
        return RenderHelper.getAABB(te.getWorldPosition().offset(-3, 0, -3), te.getWorldPosition().offset(3, 1, 3));
    }*/
}

==> touhoulittlemaid-fabric-1.21.1-0.0.3-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/tileentity/PicnicMatRender.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.block.BlockPicnicMat;
import com.github.tartaricacid.touhoulittlemaid.client.model.bedrock.SimpleBedrockModel;
import com.github.tartaricacid.touhoulittlemaid.client.resource.BedrockModelLoader;
import com.github.tartaricacid.touhoulittlemaid.tileentity.TileEntityPicnicMat;
import net.minecraft.class_1297;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_7833;
import net.minecraft.class_811;
import net.minecraft.class_827;

public class PicnicMatRender implements class_827<TileEntityPicnicMat> {
    private static final class_2960 TEXTURE = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "textures/bedrock/block/picnic_mat.png");
    private final SimpleBedrockModel<class_1297> model;
    private final class_5614.class_5615 context;

    public PicnicMatRender(class_5614.class_5615 context) {
        this.model = BedrockModelLoader.getModel(BedrockModelLoader.PICNIC_MAT);
        this.context = context;
    }

    @Override
    public void render(TileEntityPicnicMat picnicMat, float partialTick, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        class_2680 blockState = picnicMat.method_11010();
        if (blockState.method_11654(BlockPicnicMat.PART).isCenter() && this.model != null) {
            class_2350 facing = blockState.method_11654(BlockPicnicMat.FACING);
            poseStack.method_22903();
            poseStack.method_22904(0.5, 1.5, 0.5);
            poseStack.method_22907(class_7833.field_40717.rotationDegrees(180));
            poseStack.method_22907(class_7833.field_40715.rotationDegrees(180 - facing.method_10161() * 90));
            {
                this.model.getPart("basketHide").visible = !picnicMat.isEmpty(0);
                this.model.getPart("breadHide").visible = !picnicMat.isEmpty(1);
                this.model.getPart("cakeHide").visible = !picnicMat.isEmpty(2);
            }
            {
                renderFood(picnicMat, 3, -0.6f, -1.5f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 4, 0.15f, -1.2f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 5, 0.55f, -1.6f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);

                renderFood(picnicMat, 6, -0.5f, 1.65f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 7, 0.375f, 1.575f, 1.4125f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
                renderFood(picnicMat, 8, -0.05f, 1.2f, 1.25f, poseStack, bufferIn, combinedLightIn, combinedOverlayIn);
            }
            class_4588 buffer = bufferIn.getBuffer(class_1921.method_23578(TEXTURE));
            model.method_60879(poseStack, buffer, combinedLightIn, combinedOverlayIn);
            poseStack.method_22909();
        }
    }

    private void renderFood(TileEntityPicnicMat picnicMat, int slotId, float x, float y, float z, class_4587 poseStack, class_4597 bufferIn, int combinedLightIn, int combinedOverlayIn) {
        class_1799 storageItem = picnicMat.getStorageItem(slotId);
        if (!storageItem.method_7960()) {
            int count = storageItem.method_7947();
            poseStack.method_22903();
            poseStack.method_22907(class_7833.field_40713.rotationDegrees(90));
            poseStack.method_46416(x, y, z);
            poseStack.method_22905(0.4f, 0.4f, 0.4f);
            context.method_43335().method_23178(storageItem, class_811.field_4319, combinedLightIn, combinedOverlayIn, poseStack, bufferIn, picnicMat.method_10997(), 0);
            if (count >= 10) {
                int stackCount = count / 10;
                for (int i = 0; i < stackCount; i++) {
                    poseStack.method_22904(Math.sin(i) * 0.05, Math.cos(i) * 0.03, -0.07);
                    poseStack.method_22907(class_7833.field_40717.rotationDegrees((float) Math.cos(i) * 60));
                    context.method_43335().method_23178(storageItem, class_811.field_4319, combinedLightIn, combinedOverlayIn, poseStack, bufferIn, picnicMat.method_10997(), 0);
                }
            }
            poseStack.method_22909();
        }
    }

    @Override
    public boolean shouldRenderOffScreen(TileEntityPicnicMat te) {
        return true;
    }
}
